diff --git a/source/digits_hits/src/GateCoincidenceSorter.cc b/source/digits_hits/src/GateCoincidenceSorter.cc
index 91529259..0951c2c6 100644
--- a/source/digits_hits/src/GateCoincidenceSorter.cc
+++ b/source/digits_hits/src/GateCoincidenceSorter.cc
@@ -422,7 +422,12 @@ G4int GateCoincidenceSorter::ComputeSectorID(const GatePulse& pulse)
     	GateSystemComponent* comp = m_system->GetBaseComponent();
 	G4int depth=0;
 	while (comp){
-	    gkSectorNumber.push_back(comp->GetAngularRepeatNumber());
+        G4int rep_num = comp->GetAngularRepeatNumber();
+	    if (rep_num == 1)
+	        // Check for generic repeater
+	        rep_num = comp->GetGenericRepeatNumber();
+	    gkSectorNumber.push_back(rep_num);
+
 	    if ( (depth<m_depth) && ( comp->GetChildNumber() == 1)   ){
 	    	comp = comp->GetChildComponent(0);
 		depth++;
@@ -438,6 +443,7 @@ G4int GateCoincidenceSorter::ComputeSectorID(const GatePulse& pulse)
 	gm_coincSectNum = gkSectorMultiplier[0];
     }
     G4int ans=0;
+
     for (G4int i=0;i<=m_depth;i++){
     	G4int x = pulse.GetComponentID(i)%gkSectorNumber[i];
     	ans += x*gkSectorMultiplier[i];
diff --git a/source/geometry/include/GateGenericRepeater.hh b/source/geometry/include/GateGenericRepeater.hh
index 073d7e27..587b9035 100644
--- a/source/geometry/include/GateGenericRepeater.hh
+++ b/source/geometry/include/GateGenericRepeater.hh
@@ -35,6 +35,7 @@ public:
   void SetPlacementsFilename(std::string filename);
   void EnableRelativeTranslation(bool b) { mUseRelativeTranslation = b; }
   void SetPlacementList(std::vector<GatePlacement> l);
+  G4int GetRepeatNumber() { return (G4int)mPlacementsList.size(); };
 
 protected:
   GateGenericRepeaterMessenger* mMessenger; 
diff --git a/source/geometry/include/GateSystemComponent.hh b/source/geometry/include/GateSystemComponent.hh
index 41369553..81de4d1c 100644
--- a/source/geometry/include/GateSystemComponent.hh
+++ b/source/geometry/include/GateSystemComponent.hh
@@ -27,6 +27,7 @@ class G4VPhysicalVolume;
 class GateVolumePlacement;
 class GateLinearRepeater;
 class GateAngularRepeater;
+class GateGenericRepeater;
 class GateSphereRepeater;
 class GateOrbitingMove;
 class GateEccentRotMove;
@@ -293,6 +294,16 @@ class GateSystemComponent  : public GateClockDependent
     //@}
 
 
+    //@}
+
+    //! \name Access to the generic repeater properties (if any)
+    //@{
+
+    //! Finds the first generic repeater in the creator's repeater list
+    GateGenericRepeater* FindGenericRepeater();
+    //! Finds the first generic repeater's repeat number
+    G4int GetGenericRepeatNumber();
+
     //@}
 
     
diff --git a/source/geometry/src/GateSystemComponent.cc b/source/geometry/src/GateSystemComponent.cc
index 117c482d..6b4acbba 100644
--- a/source/geometry/src/GateSystemComponent.cc
+++ b/source/geometry/src/GateSystemComponent.cc
@@ -22,6 +22,7 @@
 #include "GateObjectChildList.hh"
 #include "GateLinearRepeater.hh"
 #include "GateAngularRepeater.hh"
+#include "GateGenericRepeater.hh"
 #include "GateSphereRepeater.hh"
 #include "GateSystemComponentList.hh"
 #include "GateObjectRepeaterList.hh"
@@ -660,6 +661,29 @@ G4double GateSystemComponent::GetSphereRadius()
 }
 //-------------------------------------------------------------------------------------------
 
+
+
+//-------------------------------------------------------------------------------------------
+// Finds the first generic repeater in the creator's repeater list
+GateGenericRepeater* GateSystemComponent::FindGenericRepeater()
+{
+  return FindRepeater<GateGenericRepeater>();
+}
+//-------------------------------------------------------------------------------------------
+
+
+
+//-------------------------------------------------------------------------------------------
+// Finds the first linear-repeater's repeat number
+G4int GateSystemComponent::GetGenericRepeatNumber()
+{
+  GateGenericRepeater* repeater = FindGenericRepeater();
+  return repeater ? repeater->GetRepeatNumber() : 1;
+}
+//-------------------------------------------------------------------------------------------
+
+
+
 void GateSystemComponent::setInCoincidenceWith(G4String aRsectorName )
 {
   size_t pos = GetObjectName().rfind( "/");
